<?php

add_action( 'after_setup_theme', 'shogun_sd_theme_setup' );

function shogun_sd_theme_setup() {
	
	// Features
	add_theme_support( 'menus' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'quote', 'video', 'link', 'image' ) );
	add_theme_support( 'woocommerce' ); 
	
	// Actions
	add_action( 'wp_enqueue_scripts', 'shogun_sd_theme_styles_scripts' );
	add_action( 'admin_enqueue_scripts', 'shogun_sd_load_admin_style' );
	add_action( 'admin_enqueue_scripts', 'shogun_sd_colorpicker_init' );
	add_action( 'template_redirect', 'shogun_sd_theme_adjust_content_width' );
	add_action( 'tgmpa_register', 'shogun_sd_register_required_plugins' );
	add_action( 'init', 'shogun_sd_add_editor_styles' );
	add_action( 'init', 'shogun_sd_pe_init' );
	add_action( 'get_header', 'enable_threaded_comments' );
	add_action( 'init', 'shogun_sd_initialize_cmb_meta_boxes', 9999 );
	add_action( 'init', 'shogun_sd_project_custom_init' ); 
	add_action( 'customize_controls_print_scripts', 'shogun_sd_deregister_customizer', 2 );    
		
	// Filters
	add_filter( 'dynamic_sidebar_params', 'shogun_sd_reclamation_sidebar_params' );
	add_filter( 'the_excerpt_rss', 'shogun_sd_cwc_rss_post_thumbnail' );
	add_filter( 'the_content_feed', 'shogun_sd_cwc_rss_post_thumbnail' );
	add_filter( 'request', 'shogun_sd_feed_request' );
	add_filter( 'get_comments_number', 'shogun_sd_comment_count', 0 );
	add_filter( 'excerpt_more', 'shogun_sd_custom_excerpt_more' );
	add_filter( 'excerpt_more', 'shogun_sd_no_more_jumping' );
	add_filter( 'post_class', 'shogun_sd_has_thumb_class' );
	add_filter( 'post_class', 'shogun_sd_tax_class' );
	add_filter( 'post_class', 'shogun_sd_overall_post_class' );
	add_filter( 'post_updated_messages', 'shogun_sd_project_updated_messages' );
	add_filter( 'get_search_form', 'shogun_sd_search_form' );
	add_filter( 'cmb_meta_boxes', 'shogun_sd_page_header_image_metabox' );
	add_filter( 'cmb_meta_boxes', 'shogun_sd_size_metabox' );
	add_filter( 'post_class', 'shogun_sd_size_class' );
	add_filter( 'cmb_render_imag_select_taxonomy', 'shogun_sd_imag_select_taxonomy', 10, 2 );
	add_filter( 'cmb_meta_boxes', 'shogun_sd_blog_metabox' );
	add_filter( 'cmb_meta_boxes', 'shogun_sd_portfolio_metabox' );
	add_filter( 'cmb_meta_boxes', 'shogun_sd_page_layout_metabox' );
	add_filter( 'upload_mimes', 'shogun_sd_add_custom_upload_mimes' );
	add_filter( 'body_class','shogun_sd_extra_bodyclasses' );
	
	// Remove Option Tree from user profiles
	global $shogun_sd_ot_admin;
	remove_action( 'show_user_profile', array( $shogun_sd_ot_admin, 'shogun_sd_option_tree_extra_profile_fields' ) );
	remove_action( 'edit_user_profile', array( $shogun_sd_ot_admin, 'shogun_sd_option_tree_extra_profile_fields' ) );
	remove_action( 'personal_options_update', array( $shogun_sd_ot_admin, 'shogun_sd_option_tree_save_extra_profile_fields' ) );
	remove_action( 'edit_user_profile_update', array( $shogun_sd_ot_admin, 'shogun_sd_option_tree_save_extra_profile_fields' ) );
	
	// WooCommerce integration
	remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
	remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
	remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);
	remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
	remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20, 0 );
	add_action( 'woocommerce_before_main_content', 'shogun_sd_wc_wrapper_start', 10 );
	add_action( 'woocommerce_after_main_content', 'shogun_sd_wc_wrapper_end', 10 );
	add_action( 'wp_print_scripts', 'shogun_sd_wc_de_script', 100 );
	add_filter( 'loop_shop_columns', 'shogun_sd_loop_columns' );
	add_filter( 'add_to_cart_text', 'shogun_sd_wc_custom_cart_button_text' );                        
	add_filter( 'woocommerce_product_add_to_cart_text', 'shogun_sd_wc_custom_cart_button_text' );  
	add_filter( 'woocommerce_enqueue_styles', 'shogun_sd_wc_dequeue_styles' );
	add_filter( 'woocommerce_related_products_args', 'shogun_sd_wc_related_products_limit' );
	add_filter( 'woocommerce_related_products_args','shogun_sd_wc_remove_related_products', 10 );
	$shogun_sd_wc_ppp_value = shogun_sd_wc_ppp(); 
	add_filter( 'loop_shop_per_page', create_function( '$cols', 'return '.$shogun_sd_wc_ppp_value.';' ), 20 );
	add_filter( 'add_to_cart_fragments', 'shogun_sd_wc_header_add_to_cart_fragment' );
	add_filter( 'woocommerce_product_tabs', 'shogun_sd_wc_rename_tabs', 98 );
	
}

// register and enqueue CSS styles
function shogun_sd_theme_styles_scripts () {	
	wp_register_style('theme',get_stylesheet_directory_uri().'/style.css', array(), null, 'all');
	wp_register_style('responsive',get_stylesheet_directory_uri().'/responsive.css', array(), null, 'all');
	wp_register_style('orbit',get_template_directory_uri().'/scripts/orbit/orbit-1.2.3.css', array(), null, 'all');
	wp_register_style('fontawesome',get_template_directory_uri().'/includes/font-awesome/css/font-awesome.min.css', array(), null, 'all');
		
	wp_enqueue_style('responsive');
	wp_enqueue_style('theme');
	wp_enqueue_style('orbit');
	wp_enqueue_style('fontawesome');
		
	wp_register_script('fitvids', get_template_directory_uri() . '/scripts/fitvids/jquery.fitvids.js', array('jquery'), false, true);
	wp_register_script('orbitslider', get_template_directory_uri() . '/scripts/orbit/jquery.orbit-1.2.3.js', array('jquery'), '1.2.3', false);
	wp_register_script('isotope', get_template_directory_uri() . '/scripts/isotope/jquery.isotope.min.js', array('jquery'), false, true);
	wp_register_script('retina', get_template_directory_uri() . '/scripts/retina/retina.js', array('jquery'), false, true);
	wp_register_script('smoothscroll', get_template_directory_uri() . '/scripts/smooth-scroll/jquery.smooth-scroll.js', array('jquery'), false, true);
	wp_register_script('nicescroll', get_template_directory_uri() . '/scripts/nice-scroll/jquery.nicescroll.js', array('jquery'), false, true);
	wp_register_script('perfectmasonry', get_template_directory_uri() . '/scripts/isotope/jquery.isotope.perfectmasonry.js', array('jquery'), false, true);
	wp_register_script('infinitescroll', get_template_directory_uri() . '/scripts/infinitescroll/jquery.infinitescroll.js', array('jquery'), false, true);
	wp_register_script('dotdotdot', get_template_directory_uri() . '/scripts/dotdotdot/jquery.dotdotdot.js', array('jquery'), false, true);
	wp_register_script('loader', get_template_directory_uri() . '/scripts/loader/jquery.queryloader2.js', array('jquery'), false, true);
	
	wp_enqueue_script('isotope');
	wp_enqueue_script('orbitslider');
	wp_enqueue_script('fitvids');
	wp_enqueue_script('retina');
	wp_enqueue_script('smoothscroll');
	wp_enqueue_script('nicescroll');
	wp_enqueue_script('perfectmasonry');
	wp_enqueue_script('infinitescroll');
	wp_enqueue_script('dotdotdot');
	wp_enqueue_script('loader');
}

// Load admin styles
function shogun_sd_load_admin_style() {
    wp_register_style( 'shogun_sd_admin_css', get_template_directory_uri() . '/admin-style.css', array(), null, 'all' );
    wp_enqueue_style( 'shogun_sd_admin_css' );
}

// Initialize colorpicker
function shogun_sd_colorpicker_init () {
	wp_register_style('colorpicker',get_template_directory_uri().'/scripts/colorpicker/css/colorpicker.css', array(), false, 'all');
	wp_enqueue_style('colorpicker');
	wp_register_script('colorpickerjs', get_template_directory_uri() . '/scripts/colorpicker/js/colorpicker.js', array('jquery'), false, true);
	wp_enqueue_script('colorpickerjs');
}

// Set the content width
function shogun_sd_theme_adjust_content_width() {
	if ( ! isset( $content_width ) ) {
    	$content_width = 4000;
	}
}

// Enables widgetized sidebars
if ( function_exists('register_sidebar') )

//// Sidebar widgets
//// Location: the sidebar
register_sidebar(array('name'=>'Sidebar',
	'id' => 'sidebar-1',
	'before_widget' => '',
	'after_widget' => '',
	'before_title' => '',
	'after_title' => '',
));

//// Footer widgets
//// Location: at the top of the footer, above the copyright
register_sidebar(array('name'=>'Footer',
	'id' => 'sidebar-2',
	'before_widget' => '',
	'after_widget' => '',
	'before_title' => '',
	'after_title' => '',
));

//// Expandable top
//// Location: above the header, slides down at the push of the right-hand-side button
register_sidebar(array('name'=>'Top Sliding Area',
	'id' => 'sidebar-3',
	'before_widget' => '',
	'after_widget' => '',
	'before_title' => '',
	'after_title' => '',
));

//// Add necessary HTML wrappers to widget areas
function shogun_sd_reclamation_sidebar_params($params){
	$shogun_sd_widget_name = $params[0]['widget_name'];
	$shogun_sd_widget_name = strtolower($shogun_sd_widget_name);
	$shogun_sd_widget_name = preg_replace("/[\s_]/", "-", $shogun_sd_widget_name);
	if ( $params[0]['id'] == 'sidebar-1' ) {
		$params[0]['before_title'] = '<h3>';
		$params[0]['after_title'] = '</h3><div class="clear"></div>';
		$params[0]['before_widget'] = '<div class="widget-area widget-sidebar '.$params[0]['widget_id'].' '.$shogun_sd_widget_name.'">';
		$params[0]['after_widget'] = '<div class="clear"></div></div>';
	} elseif ( $params[0]['id'] == 'sidebar-2' ) {
		$params[0]['before_title'] = '<h4>';
		$params[0]['after_title'] = '</h4><div class="clear"></div>';
		$params[0]['before_widget'] = '<div class="widget-area widget-footer '.$params[0]['widget_id'].' '.$shogun_sd_widget_name.'">';
		$params[0]['after_widget'] = '</div>';
	} elseif ( $params[0]['id'] == 'sidebar-3' ) {
		$params[0]['before_title'] = '<h4>';
		$params[0]['after_title'] = '</h4><div class="clear"></div>';
		$params[0]['before_widget'] = '<div class="widget-area widget-sliding '.$params[0]['widget_id'].' '.$shogun_sd_widget_name.'">';
		$params[0]['after_widget'] = '</div>';
	} else {
		$params[0]['before_title'] = '<h3>';
		$params[0]['after_title'] = '</h3><div class="clear"></div>';
		$params[0]['before_widget'] = '<div class="widget-area widget-sidebar '.$params[0]['widget_id'].' '.$shogun_sd_widget_name.'">';
		$params[0]['after_widget'] = '<div class="clear"></div></div>';
	}
	return $params;
}

// Activate included plugins on theme activation
require_once dirname( __FILE__ ) . '/includes/class-tgm-plugin-activation.php';
function shogun_sd_register_required_plugins() {
    $plugins = array( 
		array(
            'name'                  => 'Reactive', 
            'slug'                  => 'reactive', 
            'source'                => get_template_directory() . '/includes/plugins/reactive.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),
		array(
            'name'                  => 'Visual Composer', 
            'slug'                  => 'js_composer', 
            'source'                => get_template_directory() . '/includes/plugins/js_composer.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
			'version'				=> '10.0',
        ),
		array(
            'name'                  => 'Revolution Slider', 
            'slug'                  => 'revslider', 
            'source'                => get_template_directory() . '/includes/plugins/revslider.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),
        array(
            'name'                  => 'Advanced Recent Posts', 
            'slug'                  => 'advanced-recent-posts', 
            'source'                => get_template_directory() . '/includes/plugins/advanced-recent-posts.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),
		array(
            'name'                  => 'Contact Form', 
            'slug'                  => 'contact-form', 
            'source'                => get_template_directory() . '/includes/plugins/contact-form.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),
		array(
            'name'                  => 'Advanced SEO', 
            'slug'                  => 'advanced-seo', 
            'source'                => get_template_directory() . '/includes/plugins/advanced-seo.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),
		array(
            'name'                  => 'Custom Sidebars', 
            'slug'                  => 'custom-sidebars', 
            'source'                => get_template_directory() . '/includes/plugins/custom-sidebars.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),array(
            'name'                  => 'Social media Widget', 
            'slug'                  => 'social-media-widget', 
            'source'                => get_template_directory() . '/includes/plugins/social-media-widget.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
        ),array(
            'name'                  => 'Twitter Widget', 
            'slug'                  => 'twitter-widget', 
            'source'                => get_template_directory() . '/includes/plugins/twitter-widget.zip', 
            'required'              => false, 
            'force_activation'      => false, 
            'force_deactivation'    => true, 
		)
    );
  
    $config = array(
        'domain'            => 'satori',           
        'default_path'      => '',                          
        'parent_menu_slug'  => 'themes.php',         
        'parent_url_slug'   => 'themes.php',        
        'menu'              => 'install-required-plugins',   
        'has_notices'       => true,                        
        'is_automatic'      => true,            
        'message'           => '',               
        'strings'           => array(
            'page_title'                                => __( 'Install Required Plugins', 'satori' ),
            'menu_title'                                => __( 'Install Required Plugins', 'satori' ),
            'installing'                                => __( 'Installing Plugin: %s', 'satori' ), // %1$s = plugin name
            'oops'                                      => __( 'Something went wrong with the plugin API.', 'satori' ),
            'notice_can_install_required'               => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
            'notice_can_install_recommended'            => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends installing the following pre-packaged plugins: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_install'                     => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
            'notice_can_activate_required'              => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
            'notice_can_activate_recommended'           => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_activate'                    => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
            'notice_ask_to_update'                      => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_update'                      => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
            'install_link'                              => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                             => _n_noop( 'Activate installed plugin', 'Activate installed plugins' ),
            'return'                                    => __( 'Return to Required Plugins Installer', 'satori' ),
            'plugin_activated'                          => __( 'Plugin activated successfully.', 'satori' ),
            'complete'                                  => __( 'All plugins installed and activated successfully. %s', 'satori' ) // %1$s = dashboard link
        )
    );
    tgmpa( $plugins, $config );
}

// Initialize Visual Composer
if(function_exists('vc_set_as_theme')) vc_set_as_theme();

// Adds post thumbnails to the RSS feed
function shogun_sd_get_the_content_with_formatting ($shogun_sd_more_link_text = '(more...)', $shogun_sd_stripteaser = 0, $shogun_sd_more_file = '') {
	$shogun_sd_content = get_the_content($shogun_sd_more_link_text, $shogun_sd_stripteaser, $shogun_sd_more_file);
	$shogun_sd_content = apply_filters('the_content', $shogun_sd_content);
	$shogun_sd_content = str_replace(']]>', ']]&gt;', $shogun_sd_content);
	return $shogun_sd_content;
}
function shogun_sd_cwc_rss_post_thumbnail($shogun_sd_content) {
	global $post;
	if(has_post_thumbnail($post->ID)) {
		$shogun_sd_content = '<p>' . get_the_post_thumbnail($post->ID) .
		'</p>' . shogun_sd_get_the_content_with_formatting();
	}
	return $shogun_sd_content;
}

// Add portfolio projects to primary RSS feed
function shogun_sd_feed_request($shogun_sd_qv) { 
	if ( isset($shogun_sd_qv['feed']) && !isset($shogun_sd_qv['post_type']) )
		$shogun_sd_qv['post_type'] = array('post', 'project'); 
	return $shogun_sd_qv; 
} 

// Custom menu support
if ( function_exists( 'register_nav_menus' ) ) {
	register_nav_menus(
		array(
		  'primary-menu' => 'Primary Menu',
		  'secondary-menu' => 'Secondary Menu'
		)
	);
}

// Add WYSIWYG editor styles
function shogun_sd_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}

// Remove trackbacks from the comment count
function shogun_sd_comment_count( $shogun_sd_count ) {
	if ( ! is_admin() ) {
		global $id;
		$shogun_sd_getcomm = get_comments('status=approve&post_id=' . $id);
		$shogun_sd_sepcomm = separate_comments($shogun_sd_getcomm);
		$shogun_sd_comments_by_type = &$shogun_sd_sepcomm;
		return count($shogun_sd_comments_by_type['comment']);
	} else {
		return $shogun_sd_count;
	}
}

// Custom excerpt ellipses for 2.9+
function shogun_sd_custom_excerpt_more($more) {
	return __('Read More', 'satori').'&raquo;';
}

// No more jumping for read more link
function shogun_sd_no_more_jumping($post) {
	if(isset($post->ID)) { return '<a href="'.get_permalink($post->ID).'" class="read-more">'.'&nbsp; Continue Reading &raquo;'.'</a>'; }
}

// Add excerpts to pages
function shogun_sd_pe_init() {
	add_post_type_support( 'page', 'excerpt' );
}

// Adds a class to the post if there is a thumbnail
function shogun_sd_has_thumb_class($classes) {
	global $post;
	if( has_post_thumbnail($post->ID) ) { 
		$classes[] = 'has_thumb'; 
	}
	return $classes;
}

// Add taxonomies to post class
function shogun_sd_tax_class($shogun_sd_taxclass) {
	global $post;
	$shogun_sd_cats = get_the_terms($post->ID, 'category');
	if ( $shogun_sd_cats && ! is_wp_error( $shogun_sd_cats ) ) {
		foreach ($shogun_sd_cats as $shogun_sd_cat) {
			$shogun_sd_taxclass[] = strtolower($shogun_sd_cat->name);	
		}
	}
	$shogun_sd_tags = get_the_terms($post->ID, 'post_tag');
	if ( $shogun_sd_tags && ! is_wp_error( $shogun_sd_tags ) ) {
		foreach ($shogun_sd_tags as $shogun_sd_tag) {
			$shogun_sd_taxclass[] = strtolower($shogun_sd_tag->name);	
		}
	}
	$shogun_sd_tagports = get_the_terms($post->ID, 'type');
	if ( $shogun_sd_tagports && ! is_wp_error( $shogun_sd_tagports ) ) {
		foreach ($shogun_sd_tagports as $shogun_sd_tagport) {
			$shogun_sd_taxclass[] = strtolower($shogun_sd_tagport->name);
			$shogun_sd_taxclass[] = strtolower($shogun_sd_tagport->slug);	
		}
	}
	return $shogun_sd_taxclass;
}

// Add the .post class to portfolio items
function shogun_sd_overall_post_class($shogun_sd_classes) {
	global $post;
	if( get_post_type($post->ID) == 'project' ) { $shogun_sd_classes[] = 'post'; }
		return $shogun_sd_classes;
}


// Make theme available for translation
load_theme_textdomain('satori', get_template_directory() . '/languages');

// Enable threaded comments
function enable_threaded_comments(){
if (!is_admin()) {
	if (is_singular() AND comments_open() AND (get_option('thread_comments') == 1))
		wp_enqueue_script('comment-reply');
	}
}

// Add fancybox support
include_once( get_template_directory(). '/includes/easy-fancybox/easy-fancybox.php' );

// Add a pager
require_once( get_template_directory(). '/includes/pager/pager.php' );

// Add dropdown menus for mobile screens
include_once( get_template_directory(). '/includes/dropdown-menus/dropdown-menus.php' );

// Option Tree integration
include_once( get_template_directory(). '/includes/option-tree/index.php' );

// Initialize the metabox class
function shogun_sd_initialize_cmb_meta_boxes() {
	if ( !class_exists( 'cmb_Meta_Box' ) ) {
		require_once( get_template_directory(). '/includes/metaboxes/init.php' );
	}
}

// Create portfolio 
function shogun_sd_project_custom_init() 
{  
	$labels = array(
		'name' => _x('Projects', 'post type general name', 'satori'),
		'singular_name' => _x('Project', 'post type singular name', 'satori'),
		'all_items' => __('All Projects','satori'),
		'add_new' => _x('Add New', 'project', 'satori'),
		'add_new_item' => __('Add New Project', 'satori'),
		'edit_item' => __('Edit Project', 'satori'),
		'new_item' => __('New Project', 'satori'),
		'view_item' => __('View Project', 'satori'),
		'search_items' => __('Search Projects', 'satori'),
		'not_found' =>  __('No projects found', 'satori'),
		'not_found_in_trash' => __('No projects found in Trash', 'satori'),
		'parent_item_colon' => '',
		'menu_name' => __('Portfolio', 'satori')
	);
	$args = array(
		'labels' => $labels,
		'public' => true,
		'publicly_queryable' => true,
		'show_ui' => true,
		'show_in_menu' => true,
		'show_in_nav_menus' => true,
		'query_var' => true,
		'rewrite' => true,
		'capability_type' => 'post',
		'has_archive' => true,
		'hierarchical' => false,
		'menu_position' => null,
		'supports' => array('title','editor','author','thumbnail','excerpt','comments','post-formats')
	);
	register_post_type('project',$args);
	$labels = array(
		'name' => _x( 'Types', 'taxonomy general name' , 'satori'),
		'singular_name' => _x( 'Type', 'taxonomy singular name', 'satori' ),
		'search_items' =>  __( 'Search Types' , 'satori'),
		'all_items' => __( 'All Types', 'satori' ),
		'parent_item' => __( 'Parent Type', 'satori' ),
		'parent_item_colon' => __( 'Parent Type:', 'satori' ),
		'edit_item' => __( 'Edit Types', 'satori' ),
		'update_item' => __( 'Update Type', 'satori' ),
		'add_new_item' => __( 'Add New Type', 'satori' ),
		'new_item_name' => __( 'New Type Name', 'satori' ),
	);
	register_taxonomy('type',array('project'), array(
		'hierarchical' => true,
		'labels' => $labels,
		'show_ui' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'type' ),
		'show_in_nav_menus' => true,
		'show_tagcloud' => true
	));
}  

// Updated messages for the Project custom post type
function shogun_sd_project_updated_messages( $messages ) {
	global $post, $post_ID;

	$messages['project'] = array(
		0 => '', // Unused. Messages start at index 1.
		1 => sprintf( __('Project updated. <a href="%s">View project</a>', 'satori'), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.', 'satori'),
		3 => __('Custom field deleted.', 'satori'),
		4 => __('Project updated.', 'satori'),
		/* translators: %s: date and time of the revision */
		5 => isset($_GET['revision']) ? sprintf( __('Project restored to revision from %s', 'satori'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Project published. <a href="%s">View project</a>', 'satori'), esc_url( get_permalink($post_ID) ) ),
		7 => __('Project saved.', 'satori'),
		8 => sprintf( __('Project submitted. <a target="_blank" href="%s">Preview project</a>', 'satori'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Project scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview project</a>', 'satori'),
		  // translators: Publish box date format, see http://php.net/date
		  date_i18n( __( 'M j, Y @ G:i' , 'satori'), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Project draft updated. <a target="_blank" href="%s">Preview project</a>', 'satori'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
	);
	return $messages;
}

// Add image size for portfolio
if ( function_exists( 'shogun_sd_get_option_tree' ) && is_string ( shogun_sd_get_option_tree( 'boxdim' ) ) )  { 
	$shogun_sd_boxdim = shogun_sd_get_option_tree( 'boxdim' );
	if ( is_string(shogun_sd_get_option_tree( 'boxmar' )) ) { 
		$shogun_sd_largeboxdim = $shogun_sd_boxdim*2 + shogun_sd_get_option_tree( 'boxmar' )*2;
	} else {
		$shogun_sd_largeboxdim = $shogun_sd_boxdim*2 + 32;
	}
} else {
	$shogun_sd_largeboxdim = 552;
}
$shogun_sd_largeboxretina = $shogun_sd_largeboxdim * 2;
if ( function_exists( 'add_image_size' ) ) {
add_image_size( 'square', $shogun_sd_largeboxretina, $shogun_sd_largeboxretina, true ); 
}

// Get URL of first image in a post
function shogun_sd_catch_first_image() {
	global $post, $posts;
	$shogun_sd_first_img = '';
	ob_start();
	ob_end_clean();
	$shogun_sd_output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $shogun_sd_matches);
	$shogun_sd_first_img = $shogun_sd_matches [1] [0];
	return $shogun_sd_first_img;
}

// Custom search form
function shogun_sd_search_form( $shogun_sd_form ) {
	$shogun_sd_form = '<form role="search" method="get" class="searchform" action="' . home_url( '/' ) . '" >
	<div><input type="text" value="" name="s" class="s" /><div class="header-search-sign"></div>
	<input type="submit" id="searchsubmit" value="" />
	</div>
	</form>';
	return $shogun_sd_form;
}

// Meta box for post/page settings
function shogun_sd_page_header_image_metabox( $shogun_sd_meta_boxes ) {
	$shogun_sd_prefix = '_cmb_'; // Prefix for all fields
	$shogun_sd_meta_boxes[] = array(
		'id' => 'page_header_image_metabox',
		'title' => 'Style Settings',
		'pages' => array('page','post','project'), // post type
		'context' => 'normal',
		'priority' => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => 'Header image',
				'desc' => 'Upload the header image or enter a URL',
				'id' => $shogun_sd_prefix . 'image_upload',
				'type' => 'file',
				'save_id' => true, // save ID using true
				'allow' => array( 'url', 'attachment' ) // limit to just attachments with array( 'attachment' )
			),
			array(
				'name' => 'Hide line between header and content',
				'desc' => 'Check this if you wish to hide the separator line',
				'id' => $shogun_sd_prefix . 'page_separator',
				'type' => 'checkbox'
			),
			array(
				'name' => 'Page background color',
				'desc' => 'Choose the background color for the page',
				'id' => $shogun_sd_prefix . 'page_background_color',
				'type' => 'colorpicker'
			),
			array(
				'name' => 'Page background image',
				'desc' => 'Upload the background image for the page',
				'id' => $shogun_sd_prefix . 'page_background_image',
				'type' => 'file',
				'save_id' => true, // save ID using true
				'allow' => array( 'url', 'attachment' ) // limit to just attachments with array( 'attachment' )
			),
			array(
				'name' => 'Page background repeat',
				'desc' => 'Choose if you want to repeat the background image (i.e. create a pattern)',
				'id' => $shogun_sd_prefix . 'page_background_repeat',
				'type' => 'radio',
				'options' => array(
					array('name' => 'Repeat', 'value' => 'repeat'),
					array('name' => 'Do not repeat', 'value' => 'norepeat')
				)
			),
			array(
				'name' => 'Parallax background',
				'desc' => 'Enable parallax effect for page background',
				'id' => $shogun_sd_prefix . 'page_parallax_bck',
				'type' => 'checkbox'
			),
			array(
				'name' => 'Hide page title',
				'desc' => 'Check this if you wish to hide the page title',
				'id' => $shogun_sd_prefix . 'page_title',
				'type' => 'checkbox'
			),
			array(
				'name' => 'Page title text color',
				'desc' => 'Choose the heading text color for this particular page',
				'id' => $shogun_sd_prefix . 'page_heading_color',
				'type' => 'colorpicker'
			),
			array(
				'name' => 'Page body text color',
				'desc' => 'Choose the body text color for this particular page',
				'id' => $shogun_sd_prefix . 'page_body_color',
				'type' => 'colorpicker'
			)
		)
	);
	return $shogun_sd_meta_boxes;
}

// Meta box for post/project size settings
function shogun_sd_size_metabox( $shogun_sd_meta_boxes_size ) {
	$shogun_sd_prefix = '_cmb_'; // Prefix for all fields
	$shogun_sd_meta_boxes_size[] = array(
		'id' => 'size_metabox',
		'title' => 'Masonry Tile Settings',
		'pages' => array('post','project'), // post type
		'context' => 'normal',
		'priority' => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'id' => $shogun_sd_prefix . 'post-size',
				'name' => 'Tile size:',
				'type' => 'select',
				'desc' => 'This size will be used in the masonry-type layouts, e.g. masonry blog and masonry portfolio.',
				'options' => array(
					array ( 'name' => '1x1', 'value' => '1x1' ),
					array ( 'name' => '2x2', 'value' => '2x2' ),
					array ( 'name' => '1x2', 'value' => '1x2' ),
					array ( 'name' => '2x1', 'value' => '2x1' ),
					array ( 'name' => '2x3', 'value' => '2x3' ),
					array ( 'name' => '3x2', 'value' => '3x2' ),
					array ( 'name' => '3x3', 'value' => '3x3' ),
					array ( 'name' => '2x4', 'value' => '2x4' ),
					array ( 'name' => '4x2', 'value' => '4x2' ),
					array ( 'name' => '3x4', 'value' => '3x4' ),
					array ( 'name' => '4x3', 'value' => '4x3' ),
					array ( 'name' => '4x4', 'value' => '4x4' )
				)
			),
			array(
				'name' => 'Tile background color',
				'desc' => 'Choose the background color for the associated masonry tile',
				'id' => $shogun_sd_prefix . 'tile_background_color',
				'type' => 'colorpicker'
			),
			array(
				'name' => 'Tile text color',
				'desc' => 'Choose the text color for the associated masonry tile',
				'id' => $shogun_sd_prefix . 'tile_text_color',
				'type' => 'colorpicker'
			),
		)
	);
	return $shogun_sd_meta_boxes_size;
}

// Add custom post class for box size
function shogun_sd_size_class($classes) {
	global $post;
	$postclass = '';
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '1x1' ) {
		$postclass .= ' post-size-1x1';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '2x1' ) {
		$postclass .= ' post-size-2x1';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '1x2' ) {
		$postclass .= ' post-size-1x2';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '2x2' ) {
		$postclass .= ' post-size-2x2';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '2x3' ) {
		$postclass .= ' post-size-2x3';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '3x2' ) {
		$postclass .= ' post-size-3x2';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '3x3' ) {
		$postclass .= ' post-size-3x3';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '3x4' ) {
		$postclass .= ' post-size-3x4';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '4x3' ) {
		$postclass .= ' post-size-4x3';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '4x4' ) {
		$postclass .= ' post-size-4x4';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '4x2' ) {
		$postclass .= ' post-size-4x2';
	} 
	if ( get_post_meta($post->ID, '_cmb_post-size', true) == '2x4' ) {
		$postclass .= ' post-size-2x4';
	} 
	$classes[0] = $postclass;
	return $classes;
}

// Meta box for blog page settings
function shogun_sd_imag_select_taxonomy( $field, $meta ) {
    wp_dropdown_categories(array(
            'show_option_none' => '&#8212; Select &#8212;',
            'hierarchical' => 1,
            'taxonomy' => $field['taxonomy'],
            'orderby' => 'name', 
            'hide_empty' => 0, 
            'name' => $field['id'],
            'selected' => $meta  

        ));
    if ( !empty( $field['desc'] ) ) echo '<p class="cmb_metabox_description">' . $field['desc'] . '</p>';
}
function shogun_sd_blog_metabox( $shogun_sd_meta_boxes_blog ) {
	$shogun_sd_prefix = '_cmb_'; // Prefix for all fields
	$shogun_sd_meta_boxes_blog[] = array(
		'id' => 'blog_metabox',
		'title' => 'Blog Page Settings [Only for pages with "Blog" templates]',
		'pages' => array('page'), // post type
		'context' => 'normal',
		'priority' => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => 'Infinite scroll',
				'desc' => 'Enable infinite scroll on this page; will load posts on scroll and hide the classic pagination.',
				'id' => $shogun_sd_prefix . 'blog_infscroll',
				'type' => 'checkbox'
			),
			array(
				'name' => 'Number of posts per page',
				'desc' => 'Input any number',
				'id' => $shogun_sd_prefix . 'blog_perpage',
				'type' => 'text_small'
			),
			array(
				'name' => 'Order of posts',
				'desc' => 'Choose ascending or descending',
				'id' => $shogun_sd_prefix . 'blog_order',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'descending', 'value' => 'DESC' ),
					array ( 'name' => 'ascending', 'value' => 'ASC' )
				)
			),
			array(
				'name' => 'Order posts by',
				'desc' => 'Choose the ordering criterion',
				'id' => $shogun_sd_prefix . 'blog_orderby',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'date', 'value' => 'date' ),
					array ( 'name' => 'date modified', 'value' => 'modified' ),
					array ( 'name' => 'author', 'value' => 'author' ),
					array ( 'name' => 'comment count', 'value' => 'comment_count' ),
					array ( 'name' => 'random', 'value' => 'rand' )
				)
			),
			array(
                'name' => 'Limit posts by category',
                'desc' => 'The page will only display posts from specified category',
                'id' => $shogun_sd_prefix . 'blog_category',
                'type' => 'imag_select_taxonomy',
                'taxonomy' => 'category',
            ),
			array(
				'name' => 'Masonry units per width (only for masonry and grid template)',
				'desc' => 'Input the number of standard boxes (1x1) that will fit into content width of the masonry page',
				'id' => $shogun_sd_prefix . 'blog_masonrywidth',
				'type' => 'select',
				'options' => array(
					array ( 'name' => '', 'value' => '' ),
					array ( 'name' => '1', 'value' => '1' ),
					array ( 'name' => '2', 'value' => '2' ),
					array ( 'name' => '3', 'value' => '3' ),
					array ( 'name' => '4', 'value' => '4' ),
					array ( 'name' => '5', 'value' => '5' ),
					array ( 'name' => '6', 'value' => '6' ),
				),
				'default' => '3',
			),
			array(
				'name' => 'Caption overlays (only for masonry templates)',
				'desc' => 'Choose the behaviour mouse-hover overlays on posts.',
				'id' => $shogun_sd_prefix . 'blog_overlays',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'Show on mouse hover', 'value' => 'mousehover' ),
					array ( 'name' => 'Never show', 'value' => 'never' ),
					array ( 'name' => 'Always show', 'value' => 'always' )
				)
			)
		)
	);
	return $shogun_sd_meta_boxes_blog;
}

// Meta box for portfolio page settings
function shogun_sd_portfolio_metabox( $shogun_sd_meta_boxes_portfolio ) {
	$shogun_sd_prefix = '_cmb_'; // Prefix for all fields
	$shogun_sd_meta_boxes_portfolio[] = array(
		'id' => 'portfolio_metabox',
		'title' => 'Portfolio Page Settings [Only for pages with "Portfolio" templates]',
		'pages' => array('page'), // post type
		'context' => 'normal',
		'priority' => 'low',
		'show_names' => true, // Show field names on the left
		'fields' => array(
			array(
				'name' => 'Infinite scroll',
				'desc' => 'Enable infinite scroll on this page; will load posts on scroll and hide the classic pagination.',
				'id' => $shogun_sd_prefix . 'portfolio_infscroll',
				'type' => 'checkbox'
			),
			array(
				'name' => 'Number of projects per page',
				'desc' => 'Input any number',
				'id' => $shogun_sd_prefix . 'portfolio_perpage',
				'type' => 'text_small'
			),
			array(
				'name' => 'Order of projects',
				'desc' => 'Choose ascending or descending',
				'id' => $shogun_sd_prefix . 'portfolio_order',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'descending', 'value' => 'DESC' ),
					array ( 'name' => 'ascending', 'value' => 'ASC' )
				)
			),
			array(
				'name' => 'Order projects by',
				'desc' => 'Choose the ordering criterion',
				'id' => $shogun_sd_prefix . 'portfolio_orderby',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'date', 'value' => 'date' ),
					array ( 'name' => 'date modified', 'value' => 'modified' ),
					array ( 'name' => 'author', 'value' => 'author' ),
					array ( 'name' => 'comment count', 'value' => 'comment_count' ),
					array ( 'name' => 'random', 'value' => 'rand' )
				)
			),
			array(
                'name' => 'Limit projects by type',
                'desc' => 'The page will only display projects from specified type',
                'id' => $shogun_sd_prefix . 'portfolio_type',
                'type' => 'imag_select_taxonomy',
                'taxonomy' => 'type',
            ),
			array(
				'name' => 'Masonry units per width (only for masonry and grid templates)',
				'desc' => 'Input the number of standard boxes (1x1) that will fit into content width of the masonry page',
				'id' => $shogun_sd_prefix . 'portfolio_masonrywidth',
				'type' => 'select',
				'options' => array(
					array ( 'name' => '', 'value' => '' ),
					array ( 'name' => '1', 'value' => '1' ),
					array ( 'name' => '2', 'value' => '2' ),
					array ( 'name' => '3', 'value' => '3' ),
					array ( 'name' => '4', 'value' => '4' ),
					array ( 'name' => '5', 'value' => '5' ),
					array ( 'name' => '6', 'value' => '6' ),
				),
				'default' => '3',
			),
			array(
				'name' => 'Caption overlays (only for masonry and grid templates)',
				'desc' => 'Choose the behaviour of mouse-hover overlays on portfolio items.',
				'id' => $shogun_sd_prefix . 'portfolio_overlays',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'Show on mouse hover', 'value' => 'mousehover' ),
					array ( 'name' => 'Never show', 'value' => 'never' ),
					array ( 'name' => 'Always show', 'value' => 'always' )
				)
			),
			array(
				'name' => 'Hide filter (only for masonry and grid templates)',
				'desc' => 'Check this to hide the filter on this page.',
				'id' => $shogun_sd_prefix . 'portfolio_hide_filter',
				'type' => 'checkbox'
			),
		)
	);
	return $shogun_sd_meta_boxes_portfolio;
}

// Meta box for layout choice
function shogun_sd_page_layout_metabox( $shogun_sd_meta_boxes_page_layout ) {
	$shogun_sd_prefix = '_cmb_'; // Prefix for all fields
	$shogun_sd_meta_boxes_page_layout[] = array(
		'id' => 'page_layout_metabox',
		'title' => 'Layout',
		'pages' => array('page', 'post', 'project'), // post type
		'context' => 'side',
		'priority' => 'default',
		'show_names' => true,
		'fields' => array(
			array(
				'name' => 'Pick one:',
				'id' => $shogun_sd_prefix . 'page_layout',
				'type' => 'select',
				'options' => array(
					array ( 'name' => 'Right Sidebar', 'value' => 'right-sidebar' ),
					array ( 'name' => 'Left Sidebar', 'value' => 'left-sidebar' ),
					array ( 'name' => 'Full Width', 'value' => 'full-width' )
				),
				'default' => 'Right Sidebar'
			)
		)
	);
	return $shogun_sd_meta_boxes_page_layout;
}

// WooCommerce integration

//// Declare new content wrappers
function shogun_sd_wc_wrapper_start() {
	echo '<div class="container"><div id="content">';
}
function shogun_sd_wc_wrapper_end() {
	echo '</div>';
	if ( get_post_meta(SHOGUN_SD_FULLID, '_cmb_page_layout', true) != 'full-width' ) { 
		get_sidebar();
	}
	echo '</div>';
}

//// Remove plugin styling
function shogun_sd_wc_dequeue_styles( $enqueue_styles ) {
	unset( $enqueue_styles['woocommerce-general'] );	// Remove the gloss
	return $enqueue_styles;
}

//// Set thumbnail size
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
	add_action( 'init', 'shogun_sd_woocommerce_image_dimensions', 1 );
}
function shogun_sd_woocommerce_image_dimensions() {
  	$catalog = array(
		'width' 	=> '1000',	// px
		'height'	=> '1000',	// px
		'crop'		=> 1 		// true
	);
	$single = array(
		'width' 	=> '1000',	// px
		'height'	=> '1000',	// px
		'crop'		=> 1 		// true
	);
	$thumbnail = array(
		'width' 	=> '300',	// px
		'height'	=> '300',	// px
		'crop'		=> 0 		// false
	);
	update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
	update_option( 'shop_single_image_size', $single ); 		// Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs
}

//// Change the "Add to cart" button text 
function shogun_sd_wc_custom_cart_button_text() {
	return __( '', 'woocommerce' );
}

//// Change number or products per row
if (!function_exists('shogun_sd_loop_columns')) {
	function shogun_sd_loop_columns() {
		if ( function_exists('shogun_sd_get_option_tree') ) {
			if ( shogun_sd_get_option_tree('wc_columns_number') != '' ) {
				$shogun_sd_wc_columns = shogun_sd_get_option_tree('wc_columns_number');
				$shogun_sd_wc_columns = str_replace('%','',$shogun_sd_wc_columns);
				$shogun_sd_wc_columns = str_replace(' ','',$shogun_sd_wc_columns);
			} else {
				$shogun_sd_wc_columns = 4;
			}
		}
		return $shogun_sd_wc_columns;
	}
}

//// Change number of related products
function shogun_sd_wc_related_products_limit() {
	if ( function_exists('shogun_sd_get_option_tree') ) {
		if ( shogun_sd_get_option_tree('wc_related_number') != '' ) {
			$shogun_sd_wc_related = shogun_sd_get_option_tree('wc_related_number');
		} else {
			$shogun_sd_wc_related = 3;
		}
	}
	global $product;
	$args = array(
		'post_type'        		=> 'product',
		'no_found_rows'    		=> 1,
		'posts_per_page'   		=> $shogun_sd_wc_related,
		'ignore_sticky_posts' 	=> 1,
		'post__not_in'        	=> array($product->id)
	);
	return $args;
}

function shogun_sd_wc_remove_related_products( $args ) {
	if ( function_exists('shogun_sd_get_option_tree') ) {
		if ( shogun_sd_get_option_tree('wc_related_number') == 'none' ) {
			return array();
		}
	}
}

//// Set the number of products per page
function shogun_sd_wc_ppp() {
	$shogun_sd_wc_ppp = 12;
	if ( function_exists('shogun_sd_get_option_tree') ) {
		if ( shogun_sd_get_option_tree('wc_ppp') != '' ) {
			$shogun_sd_wc_ppp = shogun_sd_get_option_tree('wc_ppp');
		}
	}
	return $shogun_sd_wc_ppp;
}

//// Disable lightbox
function shogun_sd_wc_de_script() {
    wp_dequeue_script( 'prettyPhoto' );
	wp_dequeue_script( 'prettyPhoto-init' );
    wp_deregister_script( 'prettyPhoto' );
	wp_deregister_script( 'prettyPhoto-init' );
}

//// Ajax call for cart widget
function shogun_sd_wc_header_add_to_cart_fragment( $fragments ) {
	global $woocommerce;
	ob_start();
?>
    <a class="cart-contents" href="<?php echo $woocommerce->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'satori'); ?>">
    	<div class="cart-notification-inner">
        	<i class="fa fa-shopping-cart"></i> 
			<span class="cart-notification-number">
				<?php echo $woocommerce->cart->cart_contents_count; ?>
        	</span>
		</div>
    </a>
<?php
	$fragments['a.cart-contents'] = ob_get_clean();
	return $fragments;
}

//// Rename product tab
function shogun_sd_wc_rename_tabs( $tabs ) {
	$tabs['additional_information']['title'] = __( 'More Information', 'satori' );
	return $tabs;
}

// Allow uploading fonts
function shogun_sd_add_custom_upload_mimes($existing_mimes){
	$existing_mimes['svg'] = 'image/svg+xml';
	$existing_mimes['ttf'] = 'application/x-font-ttf'; 
	$existing_mimes['otf'] = 'application/x-font-opentype'; 
	$existing_mimes['woff'] = 'application/font-woff'; 
	$existing_mimes['eot'] = 'application/vnd.ms-fontobject';  
	return $existing_mimes;
}

// Breadcrumbs 
function shogun_sd_custom_breadcrumbs() {
  
	$showOnHome = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
	$delimiter = '<i class="fa fa-angle-right"></i>'; // delimiter between crumbs
	$home = __('Home','satori'); // text for the 'Home' link
	$showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
	$before = '<span class="breadcrumb-current">'; // tag before the current crumb
	$after = '</span>'; // tag after the current crumb
  
	global $post;
	$homeLink = get_home_url();
	
	if (is_home() || is_front_page()) {
		if ($showOnHome == 1) echo '<div class="breadcrumbs-wrap"><div class="container"><div id="breadcrumbs"><a href="' . $homeLink . '">' . $home . '</a></div>';
	} else {
		echo '<div class="breadcrumbs-wrap"><div class="container"><div id="breadcrumbs"><a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';
		if ( function_exists('is_woocommerce') && is_shop() ) {
			echo __('Shop','satori');
		} elseif ( function_exists('is_woocommerce') && is_product() ) {
			echo '<a href="' . get_permalink( woocommerce_get_page_id( 'shop' ) ) . '">' . __('Shop','satori') . '</a> ' . $delimiter . ' ' . $before . get_the_title() . $after;
		} elseif ( is_category() ) {
			$thisCat = get_category(get_query_var('cat'), false);
			if ($thisCat->parent != 0) echo get_category_parents($thisCat->parent, TRUE, ' ' . $delimiter . ' ');
			echo $before . 'Archive by category "' . single_cat_title('', false) . '"' . $after;
		} elseif ( is_tax() ) {
			$tax_archive = get_taxonomy( get_query_var( 'taxonomy' ) );;
			$tax_name = $tax_archive->labels->name;
			echo $tax_name . ' ' . $delimiter . ' ' . $before . single_tag_title( '', false ) . $after;
		} elseif ( is_search() ) {
			echo $before . 'Search results for "' . get_search_query() . '"' . $after;
		} elseif ( is_day() ) {
			echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
			echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
			echo $before . get_the_time('d') . $after;
		} elseif ( is_month() ) {
			echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
			echo $before . get_the_time('F') . $after;
		} elseif ( is_year() ) {
			echo $before . get_the_time('Y') . $after;
		} elseif ( is_single() && !is_attachment() ) {
			if ( get_post_type() != 'post' ) {
				if ( is_object_in_term($post->ID, 'type') ) { 
					$type_archive = wp_get_post_terms($post->ID, 'type');
					$type_name = $type_archive[0]->name;
					$type_slug = $type_archive[0]->slug;
					echo '<a href="' . $homeLink . '/type/' . $type_slug . '/">' . $type_name . '</a>' . $delimiter . ' ';
				}
				if ($showCurrent == 1) echo ' ' . $before . get_the_title() . $after;
			} else {
				$cat = get_the_category(); $cat = $cat[0];
				$cats = get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
				if ($showCurrent == 0) $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
				echo $cats;
				if ($showCurrent == 1) echo $before . get_the_title() . $after;
			}
		} elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
			$post_type = get_post_type_object(get_post_type());
			echo $before . $post_type->labels->singular_name . $after;
		} elseif ( is_attachment() ) {
			$parent = get_post($post->post_parent);
			$cat = get_the_category($parent->ID); $cat = $cat[0];
			echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
			echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a>';
			if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
		} elseif ( is_page() && !$post->post_parent ) {
			if ($showCurrent == 1) echo $before . get_the_title() . $after;
		} elseif ( is_page() && $post->post_parent ) {
			$parent_id  = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) {
				$page = get_page($parent_id);
				$breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
				$parent_id  = $page->post_parent;
			}
			$breadcrumbs = array_reverse($breadcrumbs);
			for ($i = 0; $i < count($breadcrumbs); $i++) {
				echo $breadcrumbs[$i];
				if ($i != count($breadcrumbs)-1) echo ' ' . $delimiter . ' ';
			}
			if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
		} elseif ( is_tag() ) {
			echo $before . 'Posts tagged "' . single_tag_title('', false) . '"' . $after;
		} elseif ( is_author() ) {
			global $author;
			$userdata = get_userdata($author);
			echo $before . 'Articles posted by ' . $userdata->display_name . $after;
		} elseif ( is_404() ) {
			echo $before . 'Error 404' . $after;
		}
		if ( get_query_var('paged') ) {
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
			echo __('Page') . ' ' . get_query_var('paged');
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
		}
		echo '</div></div></div>';
	}
}

// Generate code for header social icons
function shogun_sd_header_social_icons() {
	$shogun_sd_header_social = '';
	if ( function_exists ( 'shogun_sd_get_option_tree' ) ) { 
		$shogun_sd_headersocial = array ( "facebook", "twitter", "google-plus", "linkedin", "pinterest", "flickr", "rss", "youtube" );
		foreach ( $shogun_sd_headersocial as $shogun_sd_headersocialicon ) {
			$shogun_sd_headersocialcheck = "header_".str_replace("-","_",$shogun_sd_headersocialicon);
			if ( shogun_sd_get_option_tree ( 'header_social_target' ) == "Same tab/window" ) { $shogun_sd_target = "_self"; } else { $shogun_sd_target = "_blank"; }
			if ( is_string ( shogun_sd_get_option_tree ( $shogun_sd_headersocialcheck ) ) ) {
				$shogun_sd_header_social .= '<a href="'.shogun_sd_get_option_tree( $shogun_sd_headersocialcheck ).'" target="'.$shogun_sd_target.'"><i class="fa fa-'.$shogun_sd_headersocialicon.'"></i></a>';
			}
		}
		if ( is_string (shogun_sd_get_option_tree('header_custom_social_1_icon'))) {
			$shogun_sd_header_social .= '<a href="'.shogun_sd_get_option_tree('header_custom_social_1').'" target="'.$shogun_sd_target.'" class="header-social-custom" id="header-social-custom-1"><i class="fa '.shogun_sd_get_option_tree('header_custom_social_1_icon').'"></i></a>';	
		}
		if ( is_string (shogun_sd_get_option_tree('header_custom_social_2_icon'))) {
			$shogun_sd_header_social .= '<a href="'.shogun_sd_get_option_tree('header_custom_social_2').'" target="'.$shogun_sd_target.'" class="header-social-custom" id="header-social-custom-2"><i class="fa '.shogun_sd_get_option_tree('header_custom_social_2_icon').'"></i></a>';	
		}
	}
	$shogun_sd_header_social_code = '<div id="social-top">'.$shogun_sd_header_social.'</div>';
	echo $shogun_sd_header_social_code;
}

// Check if any header social icons have been set
function shogun_sd_header_social_icons_check() {
	$shogun_sd_hs = array ( "facebook", "twitter", "google_plus", "linkedin", "pinterest", "flickr", "rss", "youtube", "custom_social_1", "custom_social_2" );
	$shogun_sd_hs_count = 0;
	if ( function_exists ( 'shogun_sd_get_option_tree' ) ) { 
		foreach ( $shogun_sd_hs as $shogun_sd_hss ) {
			$shogun_sd_hs_check = "header_".$shogun_sd_hss;
			if ( shogun_sd_get_option_tree($shogun_sd_hs_check) != '' ) {
				$shogun_sd_hs_count++;
			}
		}
	}
	if ( $shogun_sd_hs_count > 0 ) {
		return true;
	} else {
		return false;
	}
}

// Add extra body classes
function shogun_sd_extra_bodyclasses($classes) {
	global $post;
	if ( function_exists('is_woocommerce') && is_woocommerce() ) {
		if ( is_shop() ) {
			if ( get_option('woocommerce_shop_page_id') ) {
				define ( 'SHOGUN_SD_FULLID', get_option('woocommerce_shop_page_id') );
			}
		} elseif ( is_cart() ) {
			if ( get_option('woocommerce_cart_page_id') ) {
				define ( 'SHOGUN_SD_FULLID', get_option('woocommerce_cart_page_id') );
			}
		} elseif ( is_checkout() ) {
			if ( get_option('woocommerce_checkout_page_id') ) {
				define ( 'SHOGUN_SD_FULLID', get_option('woocommerce_checkout_page_id') );
			}
		} elseif ( is_account_page() ) {
			if ( get_option('woocommerce_myaccount_page_id') ) {
				define ( 'SHOGUN_SD_FULLID', get_option('woocommerce_myaccount_page_id') );
			}
		} else {
			define ( 'SHOGUN_SD_FULLID', get_option('woocommerce_shop_page_id') );
		}
	} elseif ( !is_404() ) {
		define ( 'SHOGUN_SD_FULLID', $post->ID);
	}
	
	if ( defined ( 'SHOGUN_SD_FULLID' ) ) {
		if (get_post_meta(SHOGUN_SD_FULLID, '_cmb_page_layout', true)) {
			$classes[] = 'layout-'.get_post_meta(SHOGUN_SD_FULLID, '_cmb_page_layout', true);
		} else {
			$classes[] = 'layout-right-sidebar';
		}
	}
	if ( is_page() && !is_page_template() ) { 
		$classes[] = ' page-template-page-php';
	} 
	if ( 
		is_page_template ('page_portfolio-masonry.php') ||
		is_page_template ('page_blog-masonry.php')
	) {
		$classes[] = ' isotope';
	}
	if ( 
		is_page_template ('page_portfolio-masonry.php') || 
		is_page_template ('page_portfolio-classic.php') ||
		is_page_template ('page_portfolio-grid.php') || 
		is_tax('type') 
	) {
		$classes[] = ' portfolio page-portfolio';
	}
	if ( 
		is_page_template ('page_blog-classic.php')
	) {
		$classes[] = ' blog';
	}
	return $classes;
}

// Site-wide call-to-action section
function shogun_sd_cta() {
	if ( function_exists( 'shogun_sd_get_option_tree' ) ) {
		if ( shogun_sd_get_option_tree( 'site_wide_cta' ) != '' )  {
			$shogun_sd_sitewide_id = shogun_sd_get_option_tree( 'site_wide_cta' );
			$shogun_sd_sitewide_post = get_post($shogun_sd_sitewide_id);
			$shogun_sd_sitewide_post_content = apply_filters( 'the_content', $shogun_sd_sitewide_post->post_content );
			echo '<div class="sitewide-cta">'.$shogun_sd_sitewide_post_content.'</div>';
		}
	}
}

// Remove Custom Sidebars scripts from Theme Customizer
function shogun_sd_deregister_customizer() {
	wp_dequeue_script('cs_script');	
}

// Image class to simulate the getimagesize() function using the cURL and GD libraries 
class shogun_sd_img_info {  
    /* Determines how many characters will be read - set higher for larger files if getting errors */  
    private $range = 500000;  
    /* Constructor @access public */  
    public function __construct() {}  
    /* Method called to simulate the GD getimagesize() function w/o fopen wrapper */  
    public function getimagesize( $src )  
    {  
        $return_val = false;
        if ( function_exists( 'curl_version' ) )  
        {  
            $img_dim = $this->get_img_dim( $src );  
            $img_info = $this->get_img_info( $src );  
            if ( $img_dim[0] != '' ) { 
                $return_val = array( 
					$img_dim[0],  
                    $img_dim[1],  
                    $img_info[0],  
                    "width=\"$img_dim[0]\" height=\"$img_dim[1]\"",  
                    'colors' => $img_dim[2],  
                    'mime' => $img_info[1],  
                    'size' => $img_info[2] 
				); 
            }
        }  
        else {  
            trigger_error( 'The curl extension is not enabled.', E_USER_WARNING );  
        }  
        return $return_val;
    }  
      
    /* Private method returns dimensional info */  
    private function get_img_dim( $src )  
    {  
        $headers = array( 'Range: bytes=0-' . $this->range );  
        $curl = curl_init( $src );  
        curl_setopt( $curl, CURLOPT_SSL_VERIFYPEER, false );    
        curl_setopt( $curl, CURLOPT_HTTPHEADER, $headers );  
        curl_setopt( $curl, CURLOPT_RETURNTRANSFER, true );  
        $data = curl_exec( $curl );  
        curl_close( $curl );  
        $img = @imagecreatefromstring( $data );  
        $colors = @imagecolorstotal( $img );  
        $width = @imagesx( $img );  
        $height = @imagesy( $img );  
        @imagedestroy( $img );
        return array( $width, $height, $colors );  
    }  
    /* Private method returns filetype and size info */  
    private function get_img_info( $src )  
    {  
        $curl = curl_init( $src );  
        curl_setopt( $curl, CURLOPT_SSL_VERIFYPEER, false );       
        curl_setopt( $curl, CURLOPT_URL, $src );  
        curl_setopt( $curl, CURLOPT_HEADER, true );  
        curl_setopt( $curl, CURLOPT_NOBODY, true );  
        curl_setopt( $curl, CURLOPT_RETURNTRANSFER, true );  
        $data = str_replace( ' ', '', curl_exec( $curl ) );  
        curl_close( $curl );  
        $size = @explode( 'Content-Length:', $data );  
        /* In the event Content-Length is not sent in the header */
        if ( array_key_exists( 1, $size ) ) {  
            $size = preg_split( '/\s+/', $size[1] );  
            $filesize = (int)$size[0];  
        }  
        else      
            $filesize = $this->get_img_size( $src ); 
              
        $type = @explode( 'Content-Type:', $data );  
        $type = preg_split( '/\s+/', $type[1] );  
        if ( $type[0] === 'image/gif' )  
            $ext = 1;  
        elseif ( $type[0] === 'image/jpeg' || $type[0] === 'image/jpg' )  
            $ext = 2;      
        elseif ( $type[0] === 'image/png' )  
            $ext = 3;       
        else  
            $ext = 'N/A';  
        return array( $ext, $type[0], $filesize );  
    }  
    /* Private method returns filesize if Content-Length not sent in header */  
    private function get_img_size( $src )  
    {  
        $curl = curl_init(); 
        curl_setopt( $curl, CURLOPT_SSL_VERIFYPEER, false );  
        curl_setopt( $curl, CURLOPT_URL, $src ); 
        curl_setopt( $curl, CURLOPT_RETURNTRANSFER, true ); 
        curl_setopt( $curl, CURLOPT_HEADER, false ); 
        $data = curl_exec( $curl ); 
        curl_close( $curl ); 
        return strlen( $data ); 
    }  
}

?>